@@ -36,6 +36,8 @@
 
 #include "dbind/dbind.h"
 
+G_BEGIN_DECLS
+
 typedef struct _AtspiReference AtspiReference;
 struct _AtspiReference
 {
@@ -43,38 +45,6 @@ struct _AtspiReference
   char *path;
 };
 
-/* constants */
-#define ATSPI_DBUS_NAME_REGISTRY "org.a11y.atspi.Registry"
-#define ATSPI_DBUS_PATH_REGISTRY "/org/a11y/atspi/registry"
-#define ATSPI_DBUS_INTERFACE_REGISTRY "org.a11y.atspi.Registry"
-
-#define ATSPI_DBUS_PATH_NULL "/org/a11y/atspi/null"
-#define ATSPI_DBUS_PATH_ROOT "/org/a11y/atspi/accessible/root"
-
-#define ATSPI_DBUS_PATH_DEC "/org/a11y/atspi/registry/deviceeventcontroller"
-#define ATSPI_DBUS_INTERFACE_DEC "org.a11y.atspi.DeviceEventController"
-#define ATSPI_DBUS_INTERFACE_DEVICE_EVENT_LISTENER "org.a11y.atspi.DeviceEventListener"
-
-#define ATSPI_DBUS_INTERFACE_CACHE "org.a11y.atspi.Cache"
-#define ATSPI_DBUS_INTERFACE_ACCESSIBLE "org.a11y.atspi.Accessible"
-#define ATSPI_DBUS_INTERFACE_ACTION "org.a11y.atspi.Action"
-#define ATSPI_DBUS_INTERFACE_APPLICATION "org.a11y.atspi.Application"
-#define ATSPI_DBUS_INTERFACE_COLLECTION "org.a11y.atspi.Collection"
-#define ATSPI_DBUS_INTERFACE_COMPONENT "org.a11y.atspi.Component"
-#define ATSPI_DBUS_INTERFACE_DOCUMENT "org.a11y.atspi.Document"
-#define ATSPI_DBUS_INTERFACE_EDITABLE_TEXT "org.a11y.atspi.EditableText"
-#define ATSPI_DBUS_INTERFACE_EVENT_KEYBOARD "org.a11y.atspi.Event.Keyboard"
-#define ATSPI_DBUS_INTERFACE_EVENT_MOUSE "org.a11y.atspi.Event.Mouse"
-#define ATSPI_DBUS_INTERFACE_EVENT_OBJECT "org.a11y.atspi.Event.Object"
-#define ATSPI_DBUS_INTERFACE_HYPERLINK "org.a11y.atspi.Hyperlink"
-#define ATSPI_DBUS_INTERFACE_HYPERTEXT "org.a11y.atspi.Hypertext"
-#define ATSPI_DBUS_INTERFACE_IMAGE "org.a11y.atspi.Image"
-#define ATSPI_DBUS_INTERFACE_SELECTION "org.a11y.atspi.Selection"
-#define ATSPI_DBUS_INTERFACE_TABLE "org.a11y.atspi.Table"
-#define ATSPI_DBUS_INTERFACE_TEXT "org.a11y.atspi.Text"
-#define ATSPI_DBUS_INTERFACE_VALUE "org.a11y.atspi.Value"
-#define ATSPI_DBUS_INTERFACE_SOCKET "org.a11y.atspi.Socket"
-
 /* externs */
 extern const char *atspi_path_dec;
 extern const char *atspi_path_registry;
@@ -143,10 +113,8 @@ void _atspi_dbus_set_interfaces (AtspiAccessible *accessible, DBusMessageIter *i
 void _atspi_dbus_set_state (AtspiAccessible *accessible, DBusMessageIter *iter);
 
 #define _ATSPI_DBUS_CHECK_SIG(message, type, error, ret) \
-  if (!message) { \
-    g_warning ("at-spi: Got no message at %s line %d\n", __FILE__, __LINE__); \
+  if (!message) \
     return (ret); \
-  } \
   if (dbus_message_get_type (message) == DBUS_MESSAGE_TYPE_ERROR) \
   { \
     const char *err; \
@@ -171,8 +139,8 @@ void _atspi_dbus_set_state (AtspiAccessible *accessible, DBusMessageIter *iter);
  * be from the #ATSPIAtspiError enumeration. See #GError for information on
  * error domains.
  */
-#define ATSPI_ERROR atspi_error_quark()
-GQuark atspi_error_quark (void);
+#define ATSPI_ERROR _atspi_error_quark()
+GQuark _atspi_error_quark (void);
 
 /**
  * AtspiError:
@@ -186,4 +154,7 @@ typedef enum
 
 extern GMainLoop *atspi_main_loop;
 extern gboolean atspi_no_cache;
+
+G_END_DECLS
+
 #endif	/* _ATSPI_MISC_PRIVATE_H_ */
